<?php

namespace Hyiplab\BackOffice\Database;

use stdClass;

class QueryBuilder
{
    protected $model;

    protected $table;

    public $table_prefix;

    public $wpdb;

    private $select = '*';

    private $where;

    private $order;

    private $limit;

    private $cleanUp;

    public $attributes = [];

    public function __construct($model, $table)
    {
        $this->model = $model;
        $this->table = $table;
        global $table_prefix, $wpdb;
        $this->table_prefix = $table_prefix;
        $this->wpdb = $wpdb;
    }

    public function get($arguments = [])
    {
        $table = $this->table;
        $table = $this->table_prefix . $table;
        $sql = sprintf('SELECT %s FROM %s%s', $this->select, $table, $this->extra());
        $results = $this->wpdb->get_results($sql);
        $this->throwException();
        return $results;
    }

    public function where($field, $condition, $equal = null)
    {
        $symbol = $condition;
        if (!$this->arithmeticSym($condition)) {
            $symbol = '=';
            $equal = $condition;
        }
        if (is_array($field)) {
            $this->__where($field, symbol: $symbol);
        } else {
            $this->__where([$field => $equal], symbol: $symbol);
        }

        return $this;
    }

    public function orWhere($field, $value)
    {
        $where = $this->where;
        $where .= sprintf(" OR `%s` = '%s'", $field, $this->escape_string($value));
        $this->where = $where;
        return $this;
    }

    public function whereIn($field, $info)
    {
        $where = $this->where;
        $value = implode(',', $info);
        if (empty($where)) {
            $where = sprintf("WHERE `%s` IN(%s)", $field, $this->escape_string($value));
        } else {
            $where .= sprintf(" `%s` IN(%s)", $field, $this->escape_string($value));
        }

        $this->where = $where;
        return $this;
    }

    public function whereBetween($field, $info)
    {
        $where = $this->where;
        if (empty($where)) {
            $where = sprintf("WHERE `%s` BETWEEN '%s' AND '%s'", $field, $this->escape_string($info[0]), $this->escape_string($info[1]));
        } else {
            $where .= sprintf(" `%s` BETWEEN '%s' AND '%s'", $field, $this->escape_string($info[0]), $this->escape_string($info[1]));
        }

        $this->where = $where;
        return $this;
    }

    public function limit($limit, $offset = 0)
    {
        $this->count = $limit;
        $this->limit = 'LIMIT ' . $limit;
        if($offset){
            $this->limit .= ' OFFSET ' . $offset;
        }
        return $this;
    }

    public function skip($offset)
    {
        $this->limit .= ' OFFSET ' . $offset;

        return $this;
    }

    public function orderBy($by, $order_type = 'ASC')
    {
        $order = $this->order;

        if (is_array($by)) {
            foreach ($by as $field => $type) {
                if (is_int($field) && !preg_match('/(DESC|desc|ASC|asc)/', $type)) {
                    $field = $type;
                    $type = $order_type;
                }
                if (empty($order)) {
                    $order = sprintf('ORDER BY `%s` %s', $field, $type);
                } else {
                    $order .= sprintf(', `%s` %s', $field, $type);
                }
            }
        } else {
            if (empty($order)) {
                $order = sprintf('ORDER BY `%s` %s', $by, $order_type);
            } else {
                $order .= sprintf(', `%s` %s', $by, $order_type);
            }
        }
        $this->order = $order;

        return $this;
    }

    public function selectRaw($sql)
    {
        $result = $this->wpdb->get_results($sql);
        return $result;
    }

    public function first()
    {
        $table = $this->table;
        $table = $this->table_prefix . $table;
        $sql = $sql = sprintf('SELECT %s FROM %s%s', $this->select, $table, $this->extra());
        $result = $this->wpdb->get_row($sql);
        $this->throwException();
        if (!$result) {
            return null;
        }
        $modelInstance = new $this->model;
        $modelInstance->result_data = $result;
        $modelInstance->for_save = true;
        return $modelInstance;
    }

    public function firstOrFail()
    {
        $result = $this->first();
        if(!$result){
            abort(404);
        }
        return $result;
    }

    public function find($id)
    {
        $this->where('id', $id);
        return $this->first();
    }

    public function findOrFail($id){
        $result = $this->find($id);
        if(!$result){
            abort(404);
        }
        return $result;
    }

    public function sum($colName)
    {
        $table = $this->table;
        $table = $this->table_prefix . $table;
        $extra = $this->extra($this->cleanUp);
        $sql = sprintf('SELECT SUM(%s) FROM %s%s', $colName, $table, $extra);
        $sum = $this->wpdb->get_var($sql);
        return (int) $sum;
    }

    public function avg($colName)
    {
        $table = $this->table;
        $table = $this->table_prefix . $table;
        $extra = $this->extra($this->cleanUp);
        $sql = sprintf('SELECT AVG(%s) FROM %s%s', $colName, $table, $extra);
        $sum = $this->wpdb->get_var($sql);
        return (int) $sum;
    }

    public function min($colName)
    {
        $table = $this->table;
        $table = $this->table_prefix . $table;
        $extra = $this->extra($this->cleanUp);
        $sql = sprintf('SELECT MIN(%s) FROM %s%s', $colName, $table, $extra);
        $max = $this->wpdb->get_var($sql);
        return (int) $max;
    }

    public function max($colName)
    {
        $table = $this->table;
        $table = $this->table_prefix . $table;
        $extra = $this->extra($this->cleanUp);
        $sql = sprintf('SELECT MAX(%s) FROM %s%s', $colName, $table, $extra);
        $max = $this->wpdb->get_var($sql);
        return (int) $max;
    }

    public function count()
    {
        $table = $this->table;
        $table = $this->table_prefix . $table;
        $extra = $this->extra($this->cleanUp);
        $sql = sprintf('SELECT COUNT(*) FROM %s%s', $table, $extra);
        $count = $this->wpdb->get_var($sql);
        return (int) $count;
    }

    public function insert($data)
    {
        $table = $this->table_prefix . $this->table;
        $fields = '';
        $values = '';

        foreach ($data as $col => $value) {
            $fields .= sprintf('`%s`,', $col);
            $values .= sprintf("'%s',", $this->escape_string($value));
        }

        $fields = substr($fields, 0, -1);
        $values = substr($values, 0, -1);

        $sql = sprintf('INSERT INTO %s (%s) VALUES (%s)', $table, $fields, $values);
        $this->wpdb->query($sql);
        return $this->wpdb->insert_id;
    }

    public function update($info)
    {
        if (empty($this->where)) {
            return die('Where method is required');
        } else {
            $table = $this->table_prefix . $this->table;

            $update = '';

            foreach ($info as $col => $value) {
                $update .= sprintf("`%s`='%s', ", $col, $this->escape_string($value));
            }
            $update = substr($update, 0, -2);
            $sql = sprintf('UPDATE %s SET %s%s', $table, $update, $this->extra());
            $this->wpdb->query($sql);
        }
    }

    public function delete()
    {
        $table = $this->table_prefix . $this->table;
        if (array_key_exists('for_save', @Model::$storedData[$this->model] ?? [])) {
            $modelId = Model::$storedData[$this->model]['result_data']->id;
            $this->where('id', $modelId);
        }
        if (empty($this->where)) {
            die("Where is not set. Can't delete whole table.");
        } else {
            $sql = sprintf('DELETE FROM %s%s', $table, $this->extra());
            $this->wpdb->query($sql);
        }
    }

    public function save()
    {
        if (!array_key_exists('for_save', @Model::$storedData[$this->model] ?? [])) {
            return $this->insert($this->attributes);
        } else {
            $modelId = Model::$storedData[$this->model]['result_data']->id;
            $this->where('id', $modelId);
            $this->update($this->attributes);
        }
    }

    private function __where($info, $type = 'AND', $symbol = '=')
    {
        $where = $this->where;
        foreach ($info as $row => $value) {
            if (empty($where)) {
                $where = sprintf("WHERE `%s` $symbol '%s'", $row, $this->escape_string($value));
            } else {
                $where .= sprintf(" %s `%s` $symbol '%s'", $type, $row, $this->escape_string($value));
            }
        }
        $this->where = $where;
    }

    private function extra($cleanUp = true)
    {
        $extra = '';
        if (!empty($this->where)) {
            $extra .= ' ' . $this->where;
        }
        if (!empty($this->order)) {
            $extra .= ' ' . $this->order;
        }
        if (!empty($this->limit)) {
            $extra .= ' ' . $this->limit;
        }
        if ($cleanUp) {
            $this->cleanUp();
        }

        return $extra;
    }

    private function cleanUp()
    {
        // cleanup
        $this->where = null;
        $this->order = null;
        $this->limit = null;
    }

    public function escape_string($string = '')
    {
        return $this->wpdb->_real_escape($string);
    }

    private function arithmeticSym($symbol)
    {
        $symbols = [
            '=',
            '!=',
            '<',
            '>',
            '<=',
            '>='
        ];
        return in_array($symbol, $symbols);
    }

    public function paginate($number)
    {
        $table         = $this->table;
        $this->cleanUp = false;
        $totalData     = $this->count($table);
        $pnum          = isset($_GET['pnum']) ? intval($_GET['pnum']) : 1;
        $per_page      = $number;
        $query         = $this->limit($per_page, ($pnum - 1) * $per_page);
        $results       = $query->get($table);
        $maxpage       = ceil($totalData / $number);
        $data          = [
            'data'  => $results,
            'links' => $this->getPageLinks($totalData, $per_page)
        ];
        $data = viserToObject($data);
        return $data;
    }

    private function getPageLinks($total = 0, $limit = 10)
    {
        $page = (isset($_GET['pnum']) && is_numeric($_GET['pnum'])) ? $_GET['pnum'] : 1;

        $totalPages = ceil($total / $limit);

        // Prev + Next
        $prev = $page - 1;
        $next = $page + 1;

        $html = '';

        if ($total >= $limit) {
            $html = "<nav>";
            $html .= '<ul class="pagination justify-content-center">';
            $dNone = $page <= 1 ? 'd-none' : '';
            $html .= '<li class="page-item ' . $dNone . '"> <a class="page-link" href="' . queryToUrl(['pnum' => $prev]) .'"><i class="las la-angle-left"></i></a></li>';
            $linksPerPage = 6;
            $start        = max(1, $page - floor($linksPerPage / 2));
            $end          = min($totalPages, $start + $linksPerPage - 1);
            $start        = max(1, $end - $linksPerPage + 1);
            for ($i = $start; $i <= $end; $i++) {
                $active = ($page == $i) ? ' active' : '';
                $html .= '<li class="page-item' . $active . '"><a class="page-link" href="' . queryToUrl(['pnum' => $i]) . '">' . $i . '</a></li>';
            }

            if ($page >= $totalPages) {
                $html .= '<li class="page-item d-none">';
            } else {
                $html .= '<li class="page-item">';
            }

            $html .= '<a class="page-link" href="' . queryToUrl(['pnum' => $next]) . '"><i class="las la-angle-right"></i></a>
                    </li>
                </ul>
            </nav>';
        }
        return $html;
    }

    private function throwException()
    {
        if ($this->wpdb->last_error) {
            throw new \Exception($this->wpdb->last_error);
        }
    }
}
