<?php

namespace Hyiplab\Controllers\Admin;

use Hyiplab\BackOffice\Request;
use Hyiplab\Controllers\Controller;
use Hyiplab\Models\Transaction;
use Hyiplab\Models\Withdrawal;
use Hyiplab\Models\WithdrawMethod;

class WithdrawalController extends Controller
{

    public function log()
    {
        $request = new Request();
        if ($request->username) {
            $user = get_user_by('login', $request->username);
            if (!$user) {
                abort(404);
            }
            $pageTitle   = "Withdrawals Log - " . $user->user_login;
            $withdrawals = Withdrawal::where('user_id', $user->ID)->where('status', '!=', 0)->orderBy('id', 'desc')->paginate(vlPaginate());
        } else {
            $pageTitle   = "Withdrawals Log";
            $withdrawals = Withdrawal::where('status', '!=', 0)->orderBy('id', 'desc')->paginate(vlPaginate());
        }
        return $this->view('admin/withdraw/list', compact('pageTitle', 'withdrawals'));
    }

    public function pending()
    {
        $pageTitle   = "Pending Withdrawals";
        $withdrawals = Withdrawal::where('status', 2)->orderBy('id', 'desc')->paginate(vlPaginate());
        return $this->view('admin/withdraw/list', compact('pageTitle', 'withdrawals'));
    }

    public function approved()
    {
        $pageTitle   = "Approved Withdrawals";
        $withdrawals = Withdrawal::where('status', 1)->orderBy('id', 'desc')->paginate(vlPaginate());
        return $this->view('admin/withdraw/list', compact('pageTitle', 'withdrawals'));
    }

    public function rejected()
    {
        $pageTitle   = "Rejected Withdrawals";
        $withdrawals = Withdrawal::where('status', 3)->orderBy('id', 'desc')->paginate(vlPaginate());
        return $this->view('admin/withdraw/list', compact('pageTitle', 'withdrawals'));
    }

    public function detail()
    {
        $request    = new Request();
        $withdrawal = Withdrawal::where('id', $request->id)->where('status', '!=', 0)->firstOrFail();
        $user      = get_userdata($withdrawal->user_id);
        $method    = WithdrawMethod::where('id', $withdrawal->method_id)->first();
        $pageTitle = $user->user_login . __(' Withdraw Requested ', HYIPLAB_PLUGIN_NAME) . vlShowAmount($withdrawal->amount) . ' ' . vlCur('text');
        $this->view('admin/withdraw/detail', compact('pageTitle', 'withdrawal', 'method', 'user'));
    }

    public function reject()
    {
        $request = new Request();
        $request->validate([
            'id'      => 'required|integer',
            'details' => 'required'
        ]);

        $withdraw = Withdrawal::where('id', $request->id)->where('status', 2)->firstOrFail();

        $method                 = WithdrawMethod::where('id', $withdraw->method_id)->first();
        $data['status']         = 3;
        $data['admin_feedback'] = sanitize_text_field($request->details);
        $data['updated_at']     = current_time('mysql');
        Withdrawal::where('id', $request->id)->update($data);

        $afterBalance = hyiplabBalance($withdraw->user_id, 'interest_wallet') + $withdraw->amount;
        update_user_meta($withdraw->user_id, "hyiplab_interest_wallet", $afterBalance);

        $transaction               = new Transaction();
        $transaction->user_id      = $withdraw->user_id;
        $transaction->amount       = $withdraw->amount;
        $transaction->post_balance = $afterBalance;
        $transaction->charge       = 0;
        $transaction->trx_type     = '+';
        $transaction->remark       = 'withdraw_reject';
        $transaction->details      = vlShowAmount($withdraw->amount) . ' ' . vlCur('text') . __(' Refunded from withdrawal rejection', HYIPLAB_PLUGIN_NAME);
        $transaction->trx          = $withdraw->trx;
        $transaction->wallet_type  = 'interest_wallet';
        $transaction->created_at   = current_time('mysql');
        $transaction->save();

        $user = get_userdata($withdraw->user_id);

        vlNotify($user, 'WITHDRAW_REJECT', [
            'method_name'     => $method->name,
            'method_currency' => $withdraw->currency,
            'method_amount'   => vlShowAmount($withdraw->final_amount),
            'amount'          => vlShowAmount($withdraw->amount),
            'charge'          => vlShowAmount($withdraw->charge),
            'rate'            => vlShowAmount($withdraw->rate),
            'trx'             => $withdraw->trx,
            'post_balance'    => vlShowAmount($afterBalance),
            'admin_details'   => sanitize_text_field($request->details),
        ]);
        $notify[] = ['success', 'Withdrawal rejected successfully'];
        viserBack($notify);
    }

    public function approve()
    {
        $request = new Request();
        $request->validate([
            'id'      => 'required|integer',
            'details' => 'required'
        ]);

        $withdraw = Withdrawal::where('id', $request->id)->where('status', 2)->firstOrFail();

        $method = WithdrawMethod::where('id', $withdraw->method_id)->first();

        $data['status']         = 1;
        $data['admin_feedback'] = sanitize_text_field($request->details);
        $data['updated_at']     = current_time('mysql');
        Withdrawal::where('id', $request->id)->update($data);

        $user = get_userdata($withdraw->user_id);

        vlNotify($user, 'WITHDRAW_APPROVE', [
            'method_name'     => $method->name,
            'method_currency' => $withdraw->currency,
            'method_amount'   => vlShowAmount($withdraw->final_amount),
            'amount'          => vlShowAmount($withdraw->amount),
            'charge'          => vlShowAmount($withdraw->charge),
            'rate'            => vlShowAmount($withdraw->rate),
            'trx'             => $withdraw->trx,
            'admin_details'   => sanitize_text_field($request->details),
        ]);

        $notify[] = ['success', 'Withdrawal approved successfully'];
        viserBack($notify);
    }
}
