<?php

namespace Hyiplab\Hook;

use Hyiplab\Lib\HyipLab;
use Hyiplab\Models\Invest;
use Hyiplab\Models\Plan;
use Hyiplab\Models\Transaction;
use Hyiplab\Models\User;

class Cron
{
    public function cron()
    {
        $now = current_time('mysql');
        update_option('hyiplab_last_cron_run', $now);
        $invests = Invest::where('status', 1)->where('next_time', '<=', $now)->orderBy('last_time')->limit(100)->get();
        foreach ($invests as $invest) {
            $updateInvest                    = [];
            $updateInvest['return_rec_time'] = $invest->return_rec_time + 1;
            $updateInvest['paid']            = $invest->paid + $invest->interest;
            $updateInvest['should_pay']      = $invest->should_pay - ($invest->period > 0 ? $invest->interest : 0);
            $updateInvest['next_time']       = vlDate()->addHours($invest->hours)->toDateTime();
            $updateInvest['last_time']       = current_time('mysql');

            $afterBalance = hyiplabBalance($invest->user_id, 'interest_wallet') + $invest->interest;
            update_user_meta($invest->user_id, "hyiplab_interest_wallet", $afterBalance);
            $plan = Plan::where('id', $invest->plan_id)->first();
            if (!$plan) {
                continue;
            }
            $user = User::where('ID', $invest->user_id)->first();
            if (!$user) {
                continue;
            }
            $trx          = vlTrx();
            $transactions = [
                'user_id'      => $invest->user_id,
                'amount'       => $invest->interest,
                'post_balance' => $afterBalance,
                'charge'       => 0,
                'trx_type'     => '+',
                'details'      => vlShowAmount($invest->interest) . ' ' . vlCur('text') . __(' interest from ', HYIPLAB_PLUGIN_NAME) . esc_html($plan->name),
                'trx'          => $trx,
                'wallet_type'  => 'interest_wallet',
                'remark'       => 'interest',
                'created_at'   => current_time('mysql')
            ];
            Transaction::insert($transactions);

            if (get_option('vl_invest_return_commission') == 1) {
                $commissionType = 'invest_return_commission';
                HyipLab::levelCommission($user, $invest->interest, $commissionType, $trx);
            }

            if ($invest->return_rec_time >= $invest->period && $invest->period != -1) {
                $updateInvest['status'] = 0;

                if ($invest->capital_status == 1) {
                    $capital      = $invest->amount;
                    $afterBalance = hyiplabBalance($invest->user_id, 'interest_wallet') + $capital;
                    update_user_meta($invest->user_id, "hyiplab_interest_wallet", $afterBalance);

                    $transactions = [
                        'user_id'      => $invest->user_id,
                        'amount'       => $capital,
                        'post_balance' => $afterBalance,
                        'charge'       => 0,
                        'trx_type'     => '+',
                        'details'      => vlShowAmount($capital) . ' ' . vlCur('text') . __('capital back from', HYIPLAB_PLUGIN_NAME) . esc_html($plan->name),
                        'trx'          => $trx,
                        'wallet_type'  => 'interest_wallet',
                        'remark'       => 'interest',
                        'created_at'   => current_time('mysql')
                    ];

                    Transaction::insert($transactions);
                }
            }

            Invest::where('id', $invest->id)->update($updateInvest);

            $plan = getHyiplabPlan($invest->plan_id);

            vlNotify($user, 'INTEREST', [
                'trx'          => $trx,
                'amount'       => vlShowAmount($invest->interest),
                'plan_name'    => esc_html($plan->name),
                'post_balance' => vlShowAmount($afterBalance),
            ]);
        }
    }
}
