<?php

namespace Hyiplab\Lib;

use Hyiplab\Models\Invest;
use Hyiplab\Models\Referral;
use Hyiplab\Models\TimeSetting;
use Hyiplab\Models\Transaction;

class HyipLab
{
    /**
    * Instance of investor user
    *
    * @var object
    */
    private $user;

    /**
    * Plan which is purchasing
    *
    * @var object
    */
    private $plan;

    /**
    * Set some properties
    *
    * @param object $user
    * @param object $plan
    * @return void
    */
    public function __construct($user, $plan)
    {
        $this->user = $user;
        $this->plan = $plan;
    }

    /**
    * Invest process
    *
    * @param float $amount
    * @param string $wallet
    * @return void
    */
    public function invest($amount, $wallet){

        $plan = $this->plan;
        $user = $this->user;
        $afterBalance = hyiplabBalance($user->ID, $wallet) - $amount;
        update_user_meta($user->ID,"hyiplab_$wallet",$afterBalance);

        $trx                        = vlTrx();
        $transaction                = new Transaction();
        $transaction->user_id       = $user->ID;
        $transaction->amount        = $amount;
        $transaction->post_balance  = $afterBalance;
        $transaction->charge        = 0;
        $transaction->trx_type      = '-';
        $transaction->details       = __('Invested on ', HYIPLAB_PLUGIN_NAME) . $plan->name;
        $transaction->trx           = $trx;
        $transaction->wallet_type   = $wallet;
        $transaction->remark        = 'invest';
        $transaction->created_at = current_time('mysql');
        $transaction->save();

        $timeName = TimeSetting::where('time', $plan->time)->first();
        //start
        if ($plan->interest_type == 1) {
            $interestAmount = ($amount * $plan->interest) / 100;
        } else {
            $interestAmount = $plan->interest;
        }

        $period = ($plan->lifetime == 1) ? -1 : $plan->repeat_time;
        $next = vlDate()->addHours($plan->time)->toDateTime();

        $shouldPay = -1;
        if ($period > 0) {
            $shouldPay = $interestAmount * $period;
        }

        $invest                 = new Invest();
        $invest->user_id        = $user->ID;
        $invest->plan_id        = $plan->id;
        $invest->amount         = $amount;
        $invest->interest       = $interestAmount;
        $invest->period         = $period;
        $invest->time_name      = $timeName->name;
        $invest->hours          = $plan->time;
        $invest->next_time      = $next;
        $invest->should_pay     = $shouldPay;
        $invest->status         = 1;
        $invest->wallet_type    = $wallet;
        $invest->capital_status = $plan->capital_back;
        $invest->trx            = $trx;
        $invest->created_at     = current_time('mysql');
        $invest->save();

        if ( get_option('vl_invest_commission') == 1) {
            $commissionType = 'invest_commission';
            self::levelCommission($user, $amount, $commissionType, $trx);
        }

        vlNotify($user, 'INVESTMENT', [
            'trx'          => $trx,
            'amount'       => vlShowAmount($amount),
            'plan_name'    => $plan->name,
            'interest_amount' => vlShowAmount($interestAmount),
            'time' => $plan->lifetime == 1 ? 'lifetime' : $plan->repeat_time.' times',
            'time_name' => $plan->time_name,
            'wallet_type'  => vlKeyToTitle($wallet), 
            'post_balance' => vlShowAmount($afterBalance),
        ]);

    }

    /**
    * Give referral commission
    *
    * @param object $user
    * @param float $amount
    * @param string $commissionType
    * @param string $trx
    * @param object $setting
    * @return void
    */
    public static function levelCommission($user, $amount, $commissionType, $trx){

        $meUser = $user;
        $i = 1;
        $level = Referral::where('commission_type', $commissionType)->count();

        $transactions = [];

        while ($i <= $level) {

            $me = $meUser;

            $refer = getViserReferrer($me->ID);

            if ($refer == 0) {
                break;
            }

            $commission = Referral::where('commission_type',$commissionType)->where('level', $i)->first();

            if (!$commission) {
                break;
            }

            $com = ($amount * $commission->percent) / 100;
            $afterBalance = hyiplabBalance($refer, 'interest_wallet') + $com;
            update_user_meta($refer, "hyiplab_interest_wallet", $afterBalance);

            $transactions = [
                'user_id' => $refer,
                'amount' => $com,
                'post_balance' => $afterBalance,
                'charge' => 0,
                'trx_type' => '+',
                'details' => __('level '.$i.' Referral Commission From ',HYIPLAB_PLUGIN_NAME) . $user->user_login,
                'trx' => $trx,
                'wallet_type' =>  'interest_wallet',
                'remark'=>'referral_commission',
                'created_at' => current_time('mysql')
            ];

            Transaction::insert($transactions);

            $refUser = get_userdata($refer);

            vlNotify($refUser, 'REFERRAL_COMMISSION', [
                'amount' => vlShowAmount($com),
                'post_balance' => vlShowAmount($afterBalance),
                'trx' => $trx,
                'level' => ordinal($i),
                'type' => vlKeyToTitle($commissionType)
            ]);

            $meUser = $refUser;
            $i++;
        }
    }
}
